PAWpySeed: pawpyseed.core.projector Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Classes
pawpyseed.core.projector Namespace Reference

Defines the Projector class for evaluating AE and PS projection operators. More...

## Classes
class | Projector

## Detailed Description

Defines the Projector class for evaluating AE and PS projection operators.